# Sign vector conditions for chemical reaction networks

## Description

SageMath package for (chemical) reaction networks using sign vector conditions

To install the current version of this package, go to [sign_crn](https://pypi.org/project/sign-crn/).
See also the repository on [GitHub](https://github.com/MarcusAichmayr/sign_crn).
